"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.activatePreset = exports.loadPreset = exports.activateFilterCollection = void 0;
const path_1 = __importDefault(require("path"));
const filterCollections = [];
const presets = [];
/**
 * This function loads an addon by its name.
 * @param addonName The name of the addon to be loaded.
 */
async function loadAddon(addonName) {
    console.log(`loading addon "${addonName}"`);
    const resolve_paths = require.main?.paths ?? [];
    let cwd_path = process.cwd();
    while (cwd_path !== '/') {
        resolve_paths.push(cwd_path + '/node_modules');
        cwd_path = path_1.default.dirname(cwd_path);
    }
    const addon_path = require.resolve(addonName, {
        paths: require.main?.paths,
    });
    console.log(`addon path: ${addon_path}`);
    const addon = (await Promise.resolve(`${addon_path}`).then(s => __importStar(require(s)))).default;
    filterCollections.push(...addon.filterCollections.map(fc => {
        return {
            ...fc,
            name: addonName + ':filter_collection:' + fc.name,
        };
    }));
    presets.push(...addon.presets.map(p => {
        return {
            ...p,
            name: addonName + ':preset:' + p.name,
        };
    }));
    return;
}
/**
 * This function activates a filter collection by its name.
 * @param filterCollectionName The name of the filter collection to be activated.
 * @param env The nunjucks environment into which the filters should be loaded.
 */
async function activateFilterCollection(filterCollectionName, env) {
    let filterCollection = filterCollections.find(fc => fc.name === filterCollectionName);
    if (!filterCollection) {
        await loadAddon(filterCollectionName.split(':')[0]);
        filterCollection = filterCollections.find(fc => fc.name === filterCollectionName);
        if (!filterCollection)
            throw new Error(`Could not find filter collection "${filterCollectionName}"`);
    }
    filterCollection.filters.forEach(f => {
        env.addFilter(f.name, f.function);
    });
}
exports.activateFilterCollection = activateFilterCollection;
/**
 * This function returns a preset by its name.
 * @param presetName The name of the Preset.
 */
async function loadPreset(presetName) {
    let preset = presets.find(p => p.name === presetName);
    if (!preset) {
        await loadAddon(presetName.split(':')[0]);
        preset = presets.find(p => p.name === presetName);
        if (!preset)
            throw new Error(`Could not find preset "${presetName}`);
    }
    return preset;
}
exports.loadPreset = loadPreset;
/**
 * This function activates a preset.
 * @param preset The Preset to be activated.
 * @param env The nunjucks environment the filters, tests and globals of the preset
 * should be loaded into.
 */
async function activatePreset(preset, env) {
    preset.filterCollections.forEach(fc => {
        fc.filters.forEach(f => {
            env.addFilter(f.name, f.function);
        });
    });
    preset.globals.forEach(g => {
        env.addGlobal(g.name, g.value);
    });
    preset.tests.forEach(t => {
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        env.addTest(t.name, t.function);
    });
    env.addGlobal('templateDir', preset.templatesDir);
}
exports.activatePreset = activatePreset;
//# sourceMappingURL=addon.js.map